@@ -35,22 +35,22 @@ class CHMGenerator : public Okular::Generator
     public:
         CHMGenerator( QObject *parent, const QVariantList &args );
         ~CHMGenerator();
-        bool loadDocument( const QString & fileName, QVector< Okular::Page * > & pagesVector ) Q_DECL_OVERRIDE;
+        bool loadDocument( const QString & fileName, QVector< Okular::Page * > & pagesVector ) override;
 
-        Okular::DocumentInfo generateDocumentInfo( const QSet<Okular::DocumentInfo::Key> &keys ) const Q_DECL_OVERRIDE;
-        const Okular::DocumentSynopsis * generateDocumentSynopsis() Q_DECL_OVERRIDE;
+        Okular::DocumentInfo generateDocumentInfo( const QSet<Okular::DocumentInfo::Key> &keys ) const override;
+        const Okular::DocumentSynopsis * generateDocumentSynopsis() override;
 
-        bool canGeneratePixmap() const Q_DECL_OVERRIDE;
-        void generatePixmap( Okular::PixmapRequest * request ) Q_DECL_OVERRIDE;
+        bool canGeneratePixmap() const override;
+        void generatePixmap( Okular::PixmapRequest * request ) override;
 
-        QVariant metaData( const QString & key, const QVariant & option ) const Q_DECL_OVERRIDE;
+        QVariant metaData( const QString & key, const QVariant & option ) const override;
 
     public Q_SLOTS:
         void slotCompleted();
 
     protected:
-        bool doCloseDocument() Q_DECL_OVERRIDE;
-        Okular::TextPage* textPage( Okular::Page *page ) Q_DECL_OVERRIDE;
+        bool doCloseDocument() override;
+        Okular::TextPage* textPage( Okular::Page *page ) override;
 
     private:
         void additionalRequestData();
