@@ -18,8 +18,7 @@
 #include <QtXml/QDomElement>
 #include <QtXml/QDomText>
 
-#include <kglobal.h>
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include <core/action.h>
 #include <core/document.h>
@@ -189,7 +188,7 @@ QTextDocument* Converter::convert( const QString &fileName )
 
         if ( mDocumentInfo->mDate.isValid() )
             emit addMetaData( Okular::DocumentInfo::CreationDate,
-                      KGlobal::locale()->formatDate( mDocumentInfo->mDate, KLocale::ShortDate ) );
+                              QLocale().toString( mDocumentInfo->mDate, QLocale::ShortFormat ) );
     }
 
     QMapIterator<QString, QPair<int, int> > it( mLocalLinks );
@@ -275,7 +274,7 @@ bool Converter::convertTitleInfo( const QDomElement &element )
             if ( !convertAuthor( child, firstName, middleName, lastName, dummy, dummy ) )
                 return false;
 
-            mTitleInfo->mAuthor = QString( "%1 %2 %3" ).arg( firstName, middleName, lastName );
+            mTitleInfo->mAuthor = QStringLiteral( "%1 %2 %3" ).arg( firstName, middleName, lastName );
         } else if ( child.tagName() == QLatin1String( "book-title" ) ) {
             if ( !convertTextNode( child, mTitleInfo->mTitle ) )
                 return false;
@@ -284,7 +283,7 @@ bool Converter::convertTitleInfo( const QDomElement &element )
             if ( !convertTextNode( child, keywords ) )
                 return false;
 
-            mTitleInfo->mKeywords = keywords.split( ' ', QString::SkipEmptyParts );
+            mTitleInfo->mKeywords = keywords.split( QLatin1Char(' '), QString::SkipEmptyParts );
         } else if ( child.tagName() == QLatin1String( "date" ) ) {
             if ( !convertDate( child, mTitleInfo->mDate ) )
                 return false;
@@ -313,9 +312,8 @@ bool Converter::convertDocumentInfo( const QDomElement &element )
             if ( !convertAuthor( child, firstName, middleName, lastName, email, nickname ) )
                 return false;
 
-            mDocumentInfo->mAuthor = QString( "%1 %2 %3 <%4> (%5)" )
-                                      .arg( firstName ).arg( middleName ).arg( lastName )
-                                      .arg( email ).arg( nickname );
+            mDocumentInfo->mAuthor = QStringLiteral( "%1 %2 %3 <%4> (%5)" )
+                                      .arg( firstName, middleName, lastName, email, nickname );
         } else if ( child.tagName() == QLatin1String( "program-used" ) ) {
             if ( !convertTextNode( child, mDocumentInfo->mProducer ) )
                 return false;
@@ -379,16 +377,16 @@ bool Converter::convertTextNode( const QDomElement &element, QString &data )
 
 bool Converter::convertDate( const QDomElement &element, QDate &date )
 {
-    if ( element.hasAttribute( "value" ) )
-        date = QDate::fromString( element.attribute( "value" ), Qt::ISODate );
+    if ( element.hasAttribute( QStringLiteral("value") ) )
+        date = QDate::fromString( element.attribute( QStringLiteral("value") ), Qt::ISODate );
 
     return true;
 }
 
 bool Converter::convertSection( const QDomElement &element )
 {
-    if ( element.hasAttribute( "id" ) )
-        mSectionMap.insert( element.attribute( "id" ), mCursor->block() );
+    if ( element.hasAttribute( QStringLiteral("id") ) )
+        mSectionMap.insert( element.attribute( QStringLiteral("id") ), mCursor->block() );
 
     mSectionCounter++;
 
@@ -577,7 +575,7 @@ bool Converter::convertStyle( const QDomElement &element )
 
 bool Converter::convertBinary( const QDomElement &element )
 {
-    const QString id = element.attribute( "id" );
+    const QString id = element.attribute( QStringLiteral("id") );
 
     const QDomText textNode = element.firstChild().toText();
     QByteArray data = textNode.data().toLatin1();
@@ -605,12 +603,12 @@ bool Converter::convertCover( const QDomElement &element )
 
 bool Converter::convertImage( const QDomElement &element )
 {
-    QString href = element.attributeNS( "http://www.w3.org/1999/xlink", "href" );
+    QString href = element.attributeNS( QStringLiteral("http://www.w3.org/1999/xlink"), QStringLiteral("href") );
 
-    if ( href.startsWith( '#' ) )
+    if ( href.startsWith( QLatin1Char('#') ) )
         href = href.mid( 1 );
 
-    const QImage img = qVariantValue<QImage>( mTextDocument->resource( QTextDocument::ImageResource, QUrl( href ) ) );
+    const QImage img = qvariant_cast<QImage>( mTextDocument->resource( QTextDocument::ImageResource, QUrl( href ) ) );
 
     QTextImageFormat format;
     format.setName( href );
@@ -708,17 +706,17 @@ bool Converter::convertCite( const QDomElement &element )
 
 bool Converter::convertEmptyLine( const QDomElement& )
 {
-    mCursor->insertText( "\n\n" );
+    mCursor->insertText( QStringLiteral("\n\n") );
     return true;
 }
 
 bool Converter::convertLink( const QDomElement &element )
 {
-    QString href = element.attributeNS( "http://www.w3.org/1999/xlink", "href" );
-    QString type = element.attributeNS( "http://www.w3.org/1999/xlink", "type" );
+    QString href = element.attributeNS( QStringLiteral("http://www.w3.org/1999/xlink"), QStringLiteral("href") );
+    QString type = element.attributeNS( QStringLiteral("http://www.w3.org/1999/xlink"), QStringLiteral("type") );
 
-    if ( type == "note" )
-        mCursor->insertText( "[" );
+    if ( type == QLatin1String("note") )
+        mCursor->insertText( QStringLiteral("[") );
 
     int startPosition = mCursor->position();
 
@@ -756,14 +754,14 @@ bool Converter::convertLink( const QDomElement &element )
 
     int endPosition = mCursor->position();
 
-    if ( type == "note" )
-        mCursor->insertText( "]" );
+    if ( type == QLatin1String("note") )
+        mCursor->insertText( QStringLiteral("]") );
 
-    if ( href.startsWith( '#' ) ) { // local link
+    if ( href.startsWith( QLatin1Char('#') ) ) { // local link
         mLocalLinks.insert( href.mid( 1 ), QPair<int, int>( startPosition, endPosition ) );
     } else {
         // external link
-        Okular::BrowseAction *action = new Okular::BrowseAction( href );
+        Okular::BrowseAction *action = new Okular::BrowseAction( QUrl(href) );
         emit addAction( action, startPosition, endPosition );
     }
 
